@@ -1502,6 +1502,7 @@ function display_sub_menu(p_dossier,p_profile,p_dep,p_level)
                 if ( $('menu_table').rows.length > p_level ) {
                     $('menu_table').rows[1].remove();
                 }
+                $('sub'+p_dep).addClassName("selectedmenu");
                 var new_row = document.createElement('TR');
                 new_row.innerHTML = req.responseText;
                 $('menu_table').appendChild(new_row);
@@ -1856,14 +1857,16 @@ function set_action_related(p_obj)
     }
 }
 /**
- *@brief change a document_modele
+ *@brief Show a form to modify or add a new repository
+ *@param p_dossier 
+ *@param r_id : repository id
  */
 function stock_repo_change(p_dossier, r_id)
 {
     var queryString = "gDossier=" + p_dossier + "&op=mod_stock_repo" + "&r_id=" + r_id;
     var nTop = calcy(posY);
-    var nLeft = "200px";
-    var str_style = "top:" + nTop + "px;left:" + nLeft + ";height:auto";
+    var nLeft = "10.1562%";
+    var str_style = "top:" + nTop + "px;left:" + nLeft + ";height:auto;width:auto";
 
     removeDiv('change_stock_repo_div');
     waiting_box();
@@ -2809,6 +2812,7 @@ function unselect_other_tab(p_tab)
     } catch (e) {
         if (console)
             console.log(e.message);
+        alert_box('unselect_other_tab '+e.message);
     }
 }
 /**
