@@ -9,11 +9,14 @@
 <?php for ($i=0;$i<sizeof($array);$i++) : ?>
     <?php $class=($i%2==0)?'odd':'even';?>
 <tr class="<?php echo $class;?>">
-<td style="padding-right:55">
-<a href="javascript:void(0)" class="one" onclick="<?php echo $array[$i]['javascript']?>">
+<td style="padding-right:55px">
+<a href="javascript:void(0)" class="detail" onclick="<?php echo $array[$i]['javascript']?>">
 <?php echo $array[$i]['quick_code']?>
 </a>
 </td>
+<td>
+   <?php echo HtmlInput::history_account($array[$i]['accounting'],$array[$i]['accounting']); ?>
+</td>
 <td>
    <?php echo $array[$i]['name']?>
 </td>
